@@ -7,10 +7,10 @@
  *		HAVE_* and WITH_* defines are substituted at
  *		build time by make with values from autoconf.h.
  *
- * Version:	$Id: ab01978cf914db7e0ef6f5c0d6b1a522cea0b712 $
+ * Version:	$Id: bb74e060b9e4c54c94947d7bc9666ea95ff90370 $
  *
  */
-RCSIDH(missing_h, "$Id: ab01978cf914db7e0ef6f5c0d6b1a522cea0b712 $")
+RCSIDH(missing_h, "$Id: bb74e060b9e4c54c94947d7bc9666ea95ff90370 $")
 
 #if 1
 #  include <stdint.h>
@@ -423,7 +423,7 @@ typedef struct int128_t { uint8_t v[16]; } int128_t;
 
 /* abcd efgh -> dcba hgfe -> hgfe dcba */
 #if 1
-#if 1
+#if 0
 #    ifdef HAVE_BUILTIN_BSWAP64
 #      define ntohll(x) __builtin_bswap64(x)
 #    else
@@ -436,7 +436,7 @@ typedef struct int128_t { uint8_t v[16]; } int128_t;
 #endif
 
 #if 1
-#if 1
+#if 0
 #    ifdef HAVE_128BIT_INTEGERS
 #      define ntohlll(x) (((uint128_t)ntohll((uint64_t)(x >> 64))) | (((uint128_t)ntohll(((uint64_t) x)) << 64)))
 #    else
@@ -453,16 +453,16 @@ typedef void(*sig_t)(int);
 #endif
 
 #if 1
-#if 1
+#if !1
 HMAC_CTX *HMAC_CTX_new(void);
 #  endif
-#if 1
+#if !1
 void HMAC_CTX_free(HMAC_CTX *ctx);
 #  endif
 #endif
 
 #if 1
-#if 1
+#if !1
 static inline const unsigned char *ASN1_STRING_get0_data(const ASN1_STRING *x)
 {
 	/*
@@ -497,18 +497,25 @@ static inline int CONF_modules_load_file(const char *filename,
 #endif
 
 #if 1
-#if 1
+#if !1
 size_t SSL_get_client_random(const SSL *s, unsigned char *out, size_t outlen);
 #  endif
-#if 1
+#if !1
 size_t SSL_get_server_random(const SSL *s, unsigned char *out, size_t outlen);
 #  endif
-#if 1
+#if !1
 size_t SSL_SESSION_get_master_key(const SSL_SESSION *s,
 				  unsigned char *out, size_t outlen);
 #  endif
 #endif
 
+/*
+ *  NetBSD doesn't have O_DIRECTORY.
+ */
+#ifndef O_DIRECTORY
+#define O_DIRECTORY 0
+#endif
+
 /*
  *	Not really missing, but may be submitted as patches
  *	to the talloc project at some point in the future.
